@@ -2,7 +2,7 @@
 
 package Bundle::DBD::CSV;
 
-$VERSION = "1.04";
+$VERSION = "1.02";
 
 1;
 
@@ -18,15 +18,15 @@ Bundle::DBD::CSV - A bundle to install the DBD::CSV driver
 
 =head1 CONTENTS
 
-DBI 1.611
+DBI 1.609
 
-Text::CSV_XS 0.73
+Text::CSV_XS 0.65
 
-SQL::Statement 1.27
+SQL::Statement 1.20
 
-DBD::File 0.38
+DBD::File 0.37
 
-DBD::CSV 0.29_01
+DBD::CSV 0.25
 
 =head1 DESCRIPTION
 
@@ -41,7 +41,7 @@ This module is currently maintained by
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2010 by H.Merijn Brand
+Copyright (C) 2009      by H.Merijn Brand
 Copyright (C) 2004-2009 by Jeff Zucker
 Copyright (C) 1998-2004 by Jochen Wiedmann
 
